<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html401/loose.dtd"/>

  <xsl:variable name="evencolor">#bbbbff</xsl:variable>
  <xsl:variable name="oddcolor">#eeeeee</xsl:variable>
  <xsl:variable name="title" select="'Congress'"/>
  <xsl:variable name="displaytitle">
    <xsl:value-of select="$title"/>
  </xsl:variable>
  <xsl:param name="ST"/>

  <xsl:template match="/">
    <html>
      <head>
        <title>
          <xsl:value-of select="$displaytitle"/>
        </title>
        <xsl:call-template name="style"/>
      </head>
      <body>
        <h1>
          <xsl:value-of select="$displaytitle"/> </h1>
        <xsl:choose>
          <xsl:when test="$ST">
            <h2>Members from
              <xsl:value-of select="$ST"/></h2>
          </xsl:when>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="$ST">
            <xsl:apply-templates select="/people/person[@state = $ST]"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="/people/person"/>
          </xsl:otherwise>
        </xsl:choose>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="person">
      <div class="grid">
	<xsl:apply-templates select="." mode="photo"/>
	<br/>
	<a href="detail-{@id}.html">
          <xsl:value-of select="@name"/>
	</a>
      </div>
  </xsl:template>

 <xsl:template match="person" mode="photo">
    <xsl:param name="size" select="'medium'"/>
    <xsl:variable name="suffix">
      <xsl:choose>
        <xsl:when test="$size = 'small'">
          <xsl:text>-50px</xsl:text>
        </xsl:when>

        <xsl:when test="$size = 'medium'">
          <xsl:text>-100px</xsl:text>
        </xsl:when>
        <xsl:when test="$size = 'large'">
          <xsl:text>-200px</xsl:text>
        </xsl:when>
        <xsl:when test="$size = 'xlarge'">
          <xsl:text></xsl:text>

        </xsl:when>
        <xsl:otherwise>
          <xsl:text>-100px</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <img src="http://morpheus.dce.harvard.edu/govtrack/photos/{@id}{$suffix}.jpeg" alt="Photo of {@name}"/>
  </xsl:template>

  <xsl:template name="style">
        <style type="text/css">
        tr.evenrow {background-color: <xsl:value-of select="$evencolor"/>;}
        tr.oddrow {background-color: <xsl:value-of select="$oddcolor"/>;}
          body {font-family:Calibri, Arial, Helvetica, sans-serif;}
        h1,h2,h3,h4,h5,h6 {text-align: center;}
        div.grid {float: left; width: 175px; height: 175px; text-align: center; font-size: 0.8em;}

      </style>
  </xsl:template>
</xsl:stylesheet>
