<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html401/loose.dtd"/>

  <xsl:variable name="evencolor">#bbbbff</xsl:variable>
  <xsl:variable name="oddcolor">#eeeeee</xsl:variable>
  <xsl:variable name="title" select="'Congress'"/>
  <xsl:variable name="displaytitle">
    <xsl:value-of select="$title"/>
  </xsl:variable>
  <xsl:param name="ST"/>

  <xsl:template match="/">
    <html>
      <head>
        <title>
          <xsl:value-of select="$displaytitle"/>
        </title>
        <xsl:call-template name="style"/>
      </head>
      <body>
        <h1>
          <xsl:value-of select="$displaytitle"/> </h1>
        <xsl:choose>
          <xsl:when test="$ST">
            <h2>Members from
              <xsl:value-of select="$ST"/></h2>
          </xsl:when>
        </xsl:choose>
        <table width="100%">
          <tr>
            <th>Full Name</th>
            <th>State</th>
            <th>District</th>
            <th>Party</th>
          </tr>
          <xsl:choose>
            <xsl:when test="$ST">
              <xsl:apply-templates select="/people/person[@state = $ST]"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="/people/person"/>
            </xsl:otherwise>
          </xsl:choose>
        </table>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="person">
    <tr>
      <xsl:choose>
        <xsl:when test="position() mod 2">
          <xsl:attribute name="class"><xsl:value-of select="'oddrow'"/></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class"><xsl:value-of select="'evenrow'"/></xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td>
        <xsl:value-of select="@name"/>
      </td>
      <td>
        <xsl:value-of select="role/@state"/>
      </td>
      <td>
        <xsl:value-of select="role/@district"/>
      </td>        
      <td>
        <xsl:value-of select="role/@party"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template name="style">
        <style type="text/css">
        tr.evenrow {background-color: <xsl:value-of select="$evencolor"/>;}
        tr.oddrow {background-color: <xsl:value-of select="$oddcolor"/>;}
          body {font-family:Calibri, Arial, Helvetica, sans-serif;}
        h1,h2,h3,h4,h5,h6 {text-align: center;}
      </style>
  </xsl:template>
</xsl:stylesheet>
